@@ -296,18 +296,6 @@ meta_parse_options (int *argc, char ***argv,
       N_("Make X calls synchronous"),
       NULL
     },
-    {
-      "composite", 'c', COMPOSITE_OPTS_FLAGS, G_OPTION_ARG_NONE,
-      &my_args.composite,
-      N_("Turn compositing on"),
-      NULL
-    },
-    {
-      "no-composite", 0, COMPOSITE_OPTS_FLAGS, G_OPTION_ARG_NONE,
-      &my_args.no_composite,
-      N_("Turn compositing off"),
-      NULL
-    },
     {
       "no-force-fullscreen", 0, COMPOSITE_OPTS_FLAGS, G_OPTION_ARG_NONE,
       &my_args.no_force_fullscreen,
@@ -705,9 +693,6 @@ main (int argc, char **argv)
   g_free (meta_args.display_name);
   g_free (meta_args.client_id);
 
-  if (meta_args.composite || meta_args.no_composite)
-    meta_prefs_set_compositing_manager (meta_args.composite);
-
   if (meta_args.no_force_fullscreen)
     meta_prefs_set_force_fullscreen (FALSE);
 
